@@ -4,19 +4,18 @@ use Dancer ':syntax';
 use Dancer::Plugin::Ajax;
 use Dancer::Plugin::DBIC;
 
-use NetAddr::IP::Lite ':lower';
-
 use App::Netdisco::Web::Plugin;
 
 register_device_tab({ id => 'addresses', label => 'Addresses' });
 
 # device interface addresses
 ajax '/ajax/content/device/addresses' => sub {
-    my $ip = NetAddr::IP::Lite->new(param('q'));
-    return unless $ip;
+    my $q = param('q');
 
-    my $set = schema('netdisco')->resultset('DeviceIp')
-                ->search({ip => $ip->addr}, {order_by => 'alias'});
+    my $device = schema('netdisco')->resultset('Device')
+      ->search_for_device($q) or return;
+
+    my $set = $device->device_ips->search({}, {order_by => 'alias'});
     return unless $set->count;
 
     content_type('text/html');
